@@ -1,7 +1,9 @@
+from CTL.causal_tree.ctl.adaptive import *
 from CTL.causal_tree.ctl.ctl_base import *
 from CTL.causal_tree.ctl.ctl_honest import *
 from CTL.causal_tree.ctl.ctl_val_honest import *
 
+from CTL.causal_tree.ctl_trigger.adaptive_trigger import *
 from CTL.causal_tree.ctl_trigger.ctl_base_trigger import *
 from CTL.causal_tree.ctl_trigger.ctl_honest_trigger import *
 from CTL.causal_tree.ctl_trigger.ctl_val_honest_trigger import *
@@ -9,29 +11,46 @@ from CTL.causal_tree.ctl_trigger.ctl_val_honest_trigger import *
 
 class CausalTree:
 
-    def __init__(self, cont=False, val_honest=False, honest=False, min_size=2, max_depth=-1, val_split=0.5, weight=0.5,
-                 seed=724, quartile=False):
+    def __init__(self, cont=False, val_honest=False, honest=False, min_size=2, max_depth=-1, split_size=0.5, weight=0.5,
+                 seed=724, quartile=False, old_trigger_code=False):
         self.cont = cont
         if cont:
-            if val_honest:
-                self.tree = TriggerTreeHonestValidation(min_size=min_size, max_depth=max_depth, val_split=val_split,
-                                                        weight=weight, seed=seed, quartile=quartile)
-            elif honest:
-                self.tree = TriggerTreeHonest(min_size=min_size, max_depth=max_depth, val_split=val_split,
-                                              weight=weight, seed=seed, quartile=quartile)
+            if split_size <= 0.0 and weight <= 0.0:
+                self.tree = AdaptiveTriggerTree(min_size=min_size, max_depth=max_depth,
+                                                split_size=split_size, weight=weight, seed=seed,
+                                                quartile=quartile, old_trigger_code=old_trigger_code)
+            elif val_honest and weight > 0.0:
+                self.tree = TriggerTreeHonestValidation(min_size=min_size, max_depth=max_depth,
+                                                        split_size=split_size, weight=weight, seed=seed,
+                                                        quartile=quartile, old_trigger_code=old_trigger_code)
+            elif honest and weight > 0.0:
+                self.tree = TriggerTreeHonest(min_size=min_size, max_depth=max_depth, split_size=split_size,
+                                              weight=weight, seed=seed, quartile=quartile,
+                                              old_trigger_code=old_trigger_code)
+            elif weight > 0.0 and split_size > 0.0:
+                self.tree = TriggerTreeBase(min_size=min_size, max_depth=max_depth, split_size=split_size,
+                                            weight=weight, seed=seed, quartile=quartile,
+                                            old_trigger_code=old_trigger_code)
             else:
-                self.tree = TriggerTreeBase(min_size=min_size, max_depth=max_depth, val_split=val_split, weight=weight,
-                                            seed=seed, quartile=quartile)
+                self.tree = AdaptiveTriggerTree(min_size=min_size, max_depth=max_depth,
+                                                split_size=split_size, weight=weight, seed=seed,
+                                                quartile=quartile, old_trigger_code=old_trigger_code)
         else:
-            if val_honest:
-                self.tree = CausalTreeLearnHonestValidation(min_size=min_size, max_depth=max_depth, val_split=val_split,
-                                                            weight=weight, seed=seed)
-            elif honest:
-                self.tree = CausalTreeLearnHonest(min_size=min_size, max_depth=max_depth, val_split=val_split,
+            if split_size <= 0.0 and weight <= 0.0:
+                self.tree = AdaptiveTree(min_size=min_size, max_depth=max_depth,
+                                         split_size=split_size, weight=weight, seed=seed)
+            elif val_honest and weight > 0.0:
+                self.tree = CausalTreeLearnHonestValidation(min_size=min_size, max_depth=max_depth,
+                                                            split_size=split_size, weight=weight, seed=seed)
+            elif honest and weight > 0.0:
+                self.tree = CausalTreeLearnHonest(min_size=min_size, max_depth=max_depth, split_size=split_size,
                                                   weight=weight, seed=seed)
-            else:
-                self.tree = CausalTreeLearnBase(min_size=min_size, max_depth=max_depth, val_split=val_split,
+            elif weight > 0.0 and split_size > 0.0:
+                self.tree = CausalTreeLearnBase(min_size=min_size, max_depth=max_depth, split_size=split_size,
                                                 weight=weight, seed=seed)
+            else:
+                self.tree = AdaptiveTree(min_size=min_size, max_depth=max_depth,
+                                         split_size=split_size, weight=weight, seed=seed)
 
         self.column_num = 0
         self.fitted = False
@@ -39,6 +58,9 @@ class CausalTree:
 
     def fit(self, x, y, t):
         self.column_num = x.shape[1]
+        x = x.astype(np.float)
+        y = y.astype(np.float)
+        t = t.astype(np.float)
         self.tree.fit(x, y, t)
         self.fitted = True
         self.tree_depth = self.tree.tree_depth
@@ -329,7 +351,7 @@ class CausalTree:
 
         _assign_feature_names(self.tree.root, variable_names)
 
-    def get_variable_used(self, variable_names=None, cat=False):
+    def get_variables_used(self, variable_names=None, cat=False):
 
         if self.tree.features is None:
             if variable_names is not None:
@@ -354,7 +376,7 @@ class CausalTree:
                             list_vars.append(node.column_name)
                             list_depths.append(node.node_depth)
                 else:
-                    if node.decision not in list_vars:
+                    if node.column_name not in list_vars:
                         list_vars.append(node.column_name)
                         list_depths.append(node.node_depth)
 
